@@ -1,6 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-
 extensions = [
     'sphinx.ext.autodoc',
     'jaraco.packaging.sphinx',
@@ -12,7 +9,7 @@ html_theme = "furo"
 # Link dates and other references in the changelog
 extensions += ['rst.linker']
 link_files = {
-    '../CHANGES.rst': dict(
+    '../NEWS.rst': dict(
         using=dict(GH='https://github.com'),
         replace=[
             dict(
@@ -35,8 +32,8 @@ link_files = {
 nitpicky = True
 
 nitpick_ignore = [
-    ('py:class', 'importlib_metadata.EntryPoints'),
-    ('py:class', 'importlib_metadata.SelectableGroups'),
+    ('py:class', 'importlib.metadata.EntryPoints'),
+    ('py:class', 'importlib.metadata.SelectableGroups'),
 ]
 
 # Include Python intersphinx mapping to prevent failures
